@@ -37,6 +37,7 @@ void NIWupdate(
   double **Sn = doubleMatrix(n_dim, n_dim);
   double **mtemp = doubleMatrix(n_dim, n_dim);
 
+  /*read data */
   for (j=0; j<n_dim; j++) {
     Ybar[j] = 0;
     for (i=0; i<n_samp; i++)
@@ -45,17 +46,20 @@ void NIWupdate(
     for (k=0; k<n_dim; k++)
       Sn[j][k] = S0[j][k];
   }
-  for (j=0; j<n_dim; j++) {
-    mun[j] = (tau0*mu0[j]+n_samp*Ybar[j])/(tau0+n_samp);
-    for (k=0; k<n_dim; k++) {
-      Sn[j][k] += (tau0*n_samp)*(Ybar[j]-mu0[j])*(Ybar[k]-mu0[k])/(tau0+n_samp);
-      for (i=0; i<n_samp; i++)
-	Sn[j][k] += (Y[i][j]-Ybar[j])*(Y[i][k]-Ybar[k]);
-      /* conditioning on mu:
-	 Sn[j][k]+=tau0*(mu[j]-mu0[j])*(mu[k]-mu0[k]); 
-	 Sn[j][k]+=(Y[i][j]-mu[j])*(Y[i][k]-mu[k]); */
+
+  /* posterior updating*/
+
+  for (j=0; j<n_dim; j++) 
+    {
+      mun[j] = (tau0*mu0[j]+n_samp*Ybar[j])/(tau0+n_samp);
+      for (k=0; k<n_dim; k++) 
+	{
+	  Sn[j][k] += (tau0*n_samp)*(Ybar[j]-mu0[j])*(Ybar[k]-mu0[k])/(tau0+n_samp);
+	  for (i=0; i<n_samp; i++)
+	    Sn[j][k] += (Y[i][j]-Ybar[j])*(Y[i][k]-Ybar[k]);
+	}
     }
-  }
+
   dinv(Sn, n_dim, mtemp);
   rWish(InvSigma, mtemp, nu0+n_samp, n_dim);
   dinv(InvSigma, n_dim, Sigma);
