@@ -463,17 +463,17 @@ void cDPeco(
   Free3DMatrix(Sigma, t_samp,n_dim);
   Free3DMatrix(InvSigma, t_samp, n_dim);
   free(C);
-  Free(q);
-  Free(qq);
+  free(q);
+  free(qq);
   FreeMatrix(S_bvt, n_dim);
   FreeMatrix(Wstarmix, t_samp);
-  Free(mu_mix);
+  free(mu_mix);
   FreeMatrix(Sigma_mix, n_dim);
   FreeMatrix(InvSigma_mix, n_dim);
   free(sortC);
   free(indexC);
   free(label);
-  Free(vtemp);
+  free(vtemp);
   FreeMatrix(mtemp, n_dim);
   FreeMatrix(mtemp1, n_dim);
   FreeMatrix(onedata, 1);
