@@ -86,9 +86,9 @@ void dinv(double **X,
   for (i = 0, j = 0; j < size; j++)
     for (k = 0; k <= j; k++)
       pdInv[i++] = X[k][j];
-  F77_CALL(dpptrf)("U", &size, pdInv, &errorM);
+  F77_CALL(dpptrf)("U", &size, pdInv, &errorM FCONE);
   if (!errorM) {
-    F77_CALL(dpptri)("U", &size, pdInv, &errorM);
+    F77_CALL(dpptri)("U", &size, pdInv, &errorM FCONE);
     if (errorM) {
       if (errorM>0) {
         Rprintf("The matrix being inverted is singular. Error code %d\n", errorM);
@@ -113,7 +113,7 @@ void dinv(double **X,
     }
   }
 
-  Free(pdInv);
+  free(pdInv);
 }
 
 /* inverting a matrix, first tyring positive definite trick, and then symmetric
@@ -134,11 +134,11 @@ void dinv2D(double* X,
       pdInv[i++] = *(X+k*size+j);
 
 //Rprintf("test: %5g %5g %d",pdInv[0],pdInv[(size == 3) ? 5 : 2],i);
-  F77_CALL(dpptrf)("U", &size, pdInv, &errorM);
+  F77_CALL(dpptrf)("U", &size, pdInv, &errorM FCONE);
   if (!errorM) {
-    F77_CALL(dpptri)("U", &size, pdInv, &errorM);
+    F77_CALL(dpptri)("U", &size, pdInv, &errorM FCONE);
     if (errorM) {
-      Rprintf(emsg);
+      Rprintf("%s", emsg);
     if (errorM>0) {
       Rprintf(": The matrix being inverted is singular. Error code %d\n", errorM);
     } else {
@@ -148,7 +148,7 @@ void dinv2D(double* X,
     }
   }
   else {
-    Rprintf(emsg);
+    Rprintf("%s", emsg);
     if (errorM>0) {
       /* The matrix is not positive definite.
        * This error does occur with proper data, when the likelihood curve is flat,
@@ -178,7 +178,7 @@ void dinv2D(double* X,
   }
   }
 
-  Free(pdInv);
+  free(pdInv);
 }
 
 
@@ -212,20 +212,20 @@ void dinv2D_sym(double* X,
 
   double *work0 = doubleArray(size2);
   int test=-1;
-  F77_CALL(dsysv)("U", &size, &size, pdInv, &size, factor_out, B, &size, work0, &test, &errorM);
+  F77_CALL(dsysv)("U", &size, &size, pdInv, &size, factor_out, B, &size, work0, &test, &errorM FCONE);
   int lwork=(int)work0[0];
-  Free(work0);
+  free(work0);
 
   //Rprintf("work size %d\n",lwork);
   double *work = doubleArray(lwork);
   //Rprintf("In A: %5g %5g %5g %5g\n",pdInv[0],pdInv[1],pdInv[2],pdInv[3]);
   //Rprintf("In B: %5g %5g %5g %5g\n",B[0],B[1],B[2],B[3]);
-  F77_CALL(dsysv)("U", &size, &size, pdInv, &size, factor_out, B, &size, work, &lwork, &errorM);
-  Free(work);
+  F77_CALL(dsysv)("U", &size, &size, pdInv, &size, factor_out, B, &size, work, &lwork, &errorM FCONE);
+  free(work);
   //Rprintf("Out1: %5g %5g %5g %5g %d\n",B[0],B[1],B[2],B[3],errorM);
 
   if (errorM) {
-    Rprintf(emsg);
+    Rprintf("%s", emsg);
     if (errorM>0) {
       Rprintf(": The matrix being inverted is singular. Error code %d\n", errorM);
     } else {
@@ -241,8 +241,8 @@ void dinv2D_sym(double* X,
   }
 
   free(factor_out);
-  Free(B);
-  Free(pdInv);
+  free(B);
+  free(pdInv);
 }
 
 
@@ -256,7 +256,7 @@ void dcholdc(double **X, int size, double **L)
   for (j = 0, i = 0; j < size; j++)
     for (k = 0; k <= j; k++)
       pdTemp[i++] = X[k][j];
-  F77_CALL(dpptrf)("U", &size, pdTemp, &errorM);
+  F77_CALL(dpptrf)("U", &size, pdTemp, &errorM FCONE);
   if (errorM) {
     if (errorM>0) {
       Rprintf("The matrix being inverted was not positive definite. Error code %d\n", errorM);
@@ -274,7 +274,7 @@ void dcholdc(double **X, int size, double **L)
     }
   }
 
-  Free(pdTemp);
+  free(pdTemp);
 }
 
 /* calculate the determinant of the positive definite symmetric matrix
@@ -343,7 +343,7 @@ void dcholdc2D(double *X, int size, double *L)
   for (j = 0, i = 0; j < size; j++)
     for (k = 0; k <= j; k++)
       pdTemp[i++] = *(X+size*k+j); //pdTemp[i++] = X[k][j];
-  F77_CALL(dpptrf)("U", &size, pdTemp, &errorM);
+  F77_CALL(dpptrf)("U", &size, pdTemp, &errorM FCONE);
   if (errorM) {
     if (errorM>0) {
       Rprintf("The matrix being inverted was not positive definite. Error code %d\n", errorM);
@@ -361,10 +361,6 @@ void dcholdc2D(double *X, int size, double *L)
     }
   }
 
-  Free(pdTemp);
+  free(pdTemp);
 }
 
-int main () {
-  printf("hello world");
-  return 0;
-}
